# yum-elasticsearch Cookbook
[![Build Status](https://travis-ci.org/chasebolt/chef-yum-elasticsearch.svg?branch=master)](http://travis-ci.org/chasebolt/chef-yum-elasticsearch) [![Cookbook Version](https://img.shields.io/cookbook/v/yum-elasticsearch.svg)](https://supermarket.chef.io/cookbooks/yum-elasticsearch)

The yum-elasticsearch cookbook takes over management of the default repositoryids used with the official elasticsearch repositories. It allows attribute manipulation of the `elasticsearch` yum channel.

## Requirements
- Chef 11+
- yum version 3.2.0 or higher

### Platforms
- Fedora and RHEL based distributions (RHEL, CentOS, and Scientific Linux) are supported

## Attributes
The following attributes are set by default

```ruby
default['yum']['elasticsearch']['description'] = 'Elasticsearch Repository'
default['yum']['elasticsearch']['baseurl'] = 'http://packages.elastic.co/elasticsearch/2.x/centos'
default['yum']['elasticsearch']['gpgkey'] = 'http://packages.elastic.co/GPG-KEY-elasticsearch'
default['yum']['elasticsearch']['gpgcheck'] = true
default['yum']['elasticsearch']['enabled'] = true
default['yum']['elasticsearch']['managed'] = true

default['yum']['elasticsearch-beats']['description'] = 'Elastic Beats Repository'
default['yum']['elasticsearch-beats']['baseurl'] = 'https://packages.elastic.co/beats/yum/el/$basearch'
default['yum']['elasticsearch-beats']['gpgkey'] = 'http://packages.elastic.co/GPG-KEY-elasticsearch'
default['yum']['elasticsearch-beats']['gpgcheck'] = true
default['yum']['elasticsearch-beats']['enabled'] = true
default['yum']['elasticsearch-beats']['managed'] = true

default['yum']['elasticsearch-logstash']['description'] = 'Logstash Repository'
default['yum']['elasticsearch-logstash']['baseurl'] = 'http://packages.elastic.co/logstash/2.1/centos'
default['yum']['elasticsearch-logstash']['gpgkey'] = 'http://packages.elastic.co/GPG-KEY-elasticsearch'
default['yum']['elasticsearch-logstash']['gpgcheck'] = true
default['yum']['elasticsearch-logstash']['enabled'] = true
default['yum']['elasticsearch-logstash']['managed'] = true

default['yum']['elasticsearch-curator']['description'] = 'Curator Repository'
default['yum']['elasticsearch-curator']['baseurl'] = 'http://packages.elastic.co/curator/3/centos/$releasever'
default['yum']['elasticsearch-curator']['gpgkey'] = 'http://packages.elastic.co/GPG-KEY-elasticsearch'
default['yum']['elasticsearch-curator']['gpgcheck'] = true
default['yum']['elasticsearch-curator']['enabled'] = true
default['yum']['elasticsearch-curator']['managed'] = true


```

## Recipes
- default - Walks through node attributes and feeds a yum_resource
- parameters. The following is an example a resource generated by the
- recipe during compilation.

```ruby
  yum_repository 'elasticsearch' do
    baseurl 'http://packages.elastic.co/elasticsearch/2.x/centos'
    description 'Elasticsearch Repository'
    enabled true
    gpgcheck true
    gpgkey 'http://packages.elastic.co/GPG-KEY-elasticsearch'
  end
```

## Usage Example
To disable the elasticsearch repository through an attribute file

```ruby
default_attributes(
  :yum => {
    :elasticsearch => {
      :enabled => {
        false
       }
     }
   }
 )
```

To enable the elasticsearch repository with a wrapper cookbook, place the following in a recipe:

```ruby
include_recipe 'yum-elasticsearch'
```

## More Examples
Point the base and updates repositories at an internally hosted server.

```ruby
node.default['yum']['elasticsearch']['enabled'] = true
node.default['yum']['elasticsearch']['mirrorlist'] = nil
node.default['yum']['elasticsearch']['baseurl'] = 'https://internal.example.com/elasticsearch/6/os/x86_64'
node.default['yum']['elasticsearch']['sslverify'] = false

include_recipe 'yum-elasticsearch'
```

## Maintainers

* Chase Bolt (<chase.bolt@gmail.com>)

## License
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
